Installation — freeports_analysis 0.0.1 documentation

# Installation

There are for now 2 installation method:

- using `pip` (Recommended)

- from source

## Using `pip`

Install in a python virtual environment launching

    pip install freeports_analysis

## From source

Attention

You need to have the python `build` package installed. You can install it in your virtual environment with `pip install build`

1. Clone the repository:

    git clone https://github.com/GVoreste/analysis_finance_reports.git

2. cd into the created directory

    cd analysis_finance_reports

3. build the package

    python -m build .

4. install local package

    pip install .

5. enjoy